@@ -3,11 +3,12 @@ from logging import getLogger
 
 from .args import PATH, WARN
 from ..fit.profile.profile import pickle_profile
+from ..lib.utils import clean_path
 
 log = getLogger(__name__)
 
 
-def package_fit_profile(args, db):
+def package_fit_profile(args, data):
     '''
 ## package-fit-profile
 
@@ -18,5 +19,5 @@ to a pickle file that is distributed with this package.
 
 This command is intended for internal use only.
     '''
-    in_path, warn = args.file(PATH, rooted=False), args[WARN]
-    pickle_profile(log, in_path, warn=warn)
+    in_path, warn = clean_path(args[PATH]), args[WARN]
+    pickle_profile(in_path, warn=warn)
