@@ -1,12 +1,18 @@
 
 from math import exp
 
-from ..squeal import StatisticJournal, Constant
-from ..stoats.names import FTHR
+from ..lib import to_time
+from ..sql import StatisticJournal, Constant, ActivityGroup
+from ..names import Names
 
 # values from british cycling online calculator
 # these are upper limits
-BC_ZONES = (68, 83, 94, 105, 121, 999)
+BC_ZONES = (68, 83, 94, 105, 121)
+
+
+# these functions were used during development, but are not used in current code
+# which does calculations on dataframes for efficiency.
+# they have been left for documentation (and possibly useful from jupyter).
 
 
 def zone(hr, fthr, zones=BC_ZONES):
@@ -36,8 +42,9 @@ def edwards(hr, max_hr):
     return max(0, int(10 * (1 - (max_hr - hr) / max_hr)) - 4)
 
 
-def hr_zones_from_database(s, activity_group, time):
-    fthr = StatisticJournal.before(s, time, FTHR, Constant, activity_group)
+def hr_zones_from_database(s, local_time, activity_group):
+    activity_group = ActivityGroup.from_name(s, activity_group)
+    fthr = StatisticJournal.before(s, to_time(local_time), Names.FTHR, Constant, activity_group)
     if fthr:
         return hr_zones(fthr.value)
     else:
@@ -45,4 +52,4 @@ def hr_zones_from_database(s, activity_group, time):
 
 
 def hr_zones(fthr):
-    return [fthr * pc / 100.0 for pc in BC_ZONES]
\ No newline at end of file
+    return [fthr * pc / 100.0 for pc in BC_ZONES]
