@@ -8,8 +8,8 @@ from struct import unpack, pack
 from .records import LazyRecord, merge_duplicates
 from ..profile.fields import TypedField, TIMESTAMP_GLOBAL_TYPE, DynamicField, CompositeField
 from ..profile.types import timestamp_to_time, time_to_timestamp
+from ...names import Units
 from ...lib.data import WarnDict, tohex
-from ...stoats.names import S
 
 log = getLogger(__name__)
 FIELD_DESCRIPTION = 206
@@ -310,7 +310,7 @@ class CompressedTimestamp(Defined):
         if self.definition.timestamp_field:
             extra = {}
         else:
-            extra = {'timestamp': ((timestamp,), S)}
+            extra = {'timestamp': ((timestamp,), Units.S)}
         return self.definition.message.parse_message(self.data, self.definition, self.timestamp,
                                                      extra=extra, raw_time=raw_time,
                                                      accumulators=self._accumulators, **options)
